--[[
    Baldrick_DailyQuests by LordFarlander
    Version 1.6.136
]]--

--[[
Copyright (c) 2012-2012, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--

-- $Revision: 136 $
-- $Date: 2012-04-08 18:38:32 +0000 (Sun, 08 Apr 2012) $

local Baldrick = _G["Baldrick"]

if( not Baldrick ) then
    error( L["%s requires %s"]:format( "Baldrick_ProcessionDailyQuests", "Baldrick" ) )
    return
end--if

local L = LibStub( "AceLocale-3.0" ):GetLocale( "Baldrick_ProfessionDailyQuests" )
local LBCT = LibStub( "LibBabble-CreatureType-3.0" ):GetLookupTable()
local LBSZ = LibStub( "LibBabble-SubZone-3.0" )

if( LBSZ ) then
    LBSZ = LBSZ:GetUnstrictLookupTable()
end--if

local ZONES = {}
setmetatable( ZONES, {
    __index = function( self, key )
            return LBSZ and LBSZ[key] or L[key]
        end } )

local Humanoid = LBCT["Humanoid"]

local professionDailyQuests = {
    --[[
        These are the availiable fields; required are marked with a *, optional fields must be nil:
        questIDs: *Either a number with a questID or a table of numbers with questIDs.
        questItems: *A table of items required for the quest.  The one with an index of default is what will show on the button
                    The fields for items are:
                        questItem: the itemID of the item
                        questItemCount: the MINIMUM number required (the comparison will be >= )
        zones: A zone name this quest is valid for, ot a table of zone names
        subZones: A subzone name this quest is valid for, ot a table of zone names
        target: NPCId of target to check for, or table of NPCIds for multiple targets
        addionalEvents: Either a string with the name of an additional event that this quest should be checked when fired,
                        or a table of strings with names.  Events from a library that uses CallBackHandler can be registered for
                        buy using LibraryName:Event syntax.
        func: A function that takes two parameters.  The first parameter is the quest data iself, the second parameter will hold
              the questID being used.  If used this function must return a boolean, true if this quest is valid to show on the button.
        onEVENT: A function that will be ran whenever the event is encountered and the quest is registered for it.
        ]]--
    --Cooking
    --Northrend
    {
        --Cheese for Glowergold
        questIDs = { 13103, 13115, },
        --Empty Cheese Serving Platter, Aged Dalaran Cheese, Half Full Wine Glass
        questItems = { default = { questItem = 43139, },
                                 { questItem = 43137, },
                                 { questItem = 43138, questItemCount = 6, },
                     },
    },
    {
        --Infused Mushroom Meatloaf
        questIDs = { 13100, 13112, },
        --Meatloaf Pan, Infused Mushroom, Chilled Meat
        questItems = { default = { questItem = 43101, },
                                 { questItem = 43100, questItemCount = 4, },
                                 { questItem = 43013, questItemCount = 2, },
                     },
    },
    {
        --Mustard Dogs!
        questIDs = { 13107, 13116, },
        --Empty Picnic Basket, Rhino Dog, Mustard Herb
        questItems = { default = { questItem = 43142, },
                                 { questItem = 34752, questItemCount = 4, },
                                 { questItem = 43143, questItemCount = 4, },
                     },
    },
    {
        --Sewer Stew
        questIDs = { 13102, 13114, },
        --Stew Cookpot, Chilled Meat, Crystal Song Carrot
        questItems = { default = { questItem = 43147, },
                                 { questItem = 43013, questItemCount = 4, },
                                 { questItem = 43148, questItemCount = 4, },
                     },
    },
    --Outland
    {
        --Revenge is Tasty
        questIDs = 11377,
        --Cooking Pot: Kaliri Stew, Giant Kaliri Wing, Warp Burger
        questItems = { default = { questItem = 33837, },
                                 { questItem = 33838, },
                                 { questItem = 27659, questItemCount = 3, },
                     },
    },
    {
        --Soup for the Soul
        questIDs = 11381,
        --Cooking Pot: Spiritual Soup, Roasted Clefthoof
        questItems = { default = { questItem = 33851, }, { questItem = 27658, questItemCount = 4, }, },
        zones = ZONES["Nagrand"],
        subZones = ZONES["Ancestral Grounds"],
    },
    {
        --Super Hot Stew
        questIDs = 11379,
        --Cooking Pot: Demon Broiled Surprise, Mok'Nathal Shortribs, Crunchy Serpent
        questItems = { default = { questItem = 33852, },
                                 { questItem = 31672, questItemCount = 2, },
                                 { questItem = 31673, },
                     },
        --Abyssal Flamebringer
        targets = 19973,
        func = function() return UnitIsDead( "playertarget" ); end,
    },
    --Cataclysm
    {
        --A Round for the Guards
        questIDs = 29351,
        --Ironforge Rations
        questItems = { default = { questItem = 69981, }, },
        --Ironforge Guard
        targets = { 5595, 37775, 42783, },
        func = function() return not UnitIsDead( "playertarget" ); end,
    },
    {
        --Mulgore Spice Bread
        questIDs = 29363,
        --Mulgore Spices, Spice Bread
        questItems = { default = { questItem = 69997, }, { questItem = 30816, }, },
    },
    {
        --Pining for Nuts
        questIDs = 29358,
        --Mulgore Pine Cone
        questItems = { default = { questItem = 69990, }, },
    },
    {
        --Ribs for the Sentinels
        questIDs = 29318,
        --Uncooked Ribs
        questItems = { default = { questItem = 69904, }, },
    },
    {
        --Ribs for the Sentinels
        questIDs = 29318,
        --Delicious Ribs
        questItems = { default = { questItem = 69904, }, },
        --Darnassus Sentinel
        targets = 4262,
    },

    --Fishing
    --Northrend
    {
        --The Ghostfish
        questIDs = 13830,
        --Phantom Ghostfish
        questItems = { default = { questItem = 45902, }, },
    },
    {
        --Monsterbelly Appetite
        questIDs = 13836,
        --Bloated Monsterbelly
        questItems = { default = { questItem = 45328, }, },
    },
    --Outland
    {
        --Shrimpin' Ain't Easy
        questIDs = 11668,
        --Bloated Barbed Gill Trout
        questItems = { default = { questItem = 35313, }, },
    },
    --Cataclysm
    {
        --A Golden Opportunity
        questIDs = 26572,
        --Razgar's Fillet Knife
        questItems = { default = { questItem = 58955, }, },
        --Drowned Thunder Lizard
        targets = 39464,
    },
    {
        --A Staggering Effort
        questIDs = 29346,
        --Stag Eye
        questItems = { default = { questItem = 58949, }, },
    },
    {
        --Big Gulp
        questIDs = 26488,
        --Royal Monkfish
        questItems = { default = { questItem = 58856, }, },
    },
    {
        --Diggin' For Worms
        questIDs = 26420,
        --Overgrown Earthworm
        questItems = { default = { questItem = 58788, }, },
    },
    {
        --Fish fer Squirky
        questIDs = 29344,
        --Blind Minnow
        questItems = { default = { questItem = 69933, }, },
        --Squirky
        targets = 53544,
    },
    {
        --Like Pike?
        questIDs = 29320,
        --Corpse Worm
        questItems = { default = { questItem = 69907, }, },
    },
    {
        --Live Bait
        questIDs = 29347,
        --Grimnur's Bait
        questItems = { default = { questItem = 69940, questItemCount = 1, } },
        zones = ZONES["Dun Morogh"],
        subZones = ZONES["Helm's Bed Lake"],
        additionalEvents = { "LibLordFarlander-SpecialEvents-Aura-4.0:PlayerBuffGained",
                             "LibLordFarlander-SpecialEvents-Aura-4.0:PlayerBuffLost"
                           },
        func = function( quest ) return SpecialEventsAura:UnitHasBuff( "player", quest.buff ); end,
        --nonstandard
        --Grimnur's Bait
        buff = 99435,
    },
    {
        --Moat Monster!
        questIDs = 29361,
        --Moat Monster Feeding Kit
        questItems = { default = { questItem = 69999, questItemCount = 1, } },
    },
    {
        --Moat Monster!
        questIDs = 29361,
        --Alliance Decoy Kit
        questItems = { default = { questItem = 69998, questItemCount = 1, } },
        zones = ZONES["Undercity"],
    },
    {
        --Moat Monster!
        questIDs = 29361,
        --Bloated Frog
        questItems = { default = { questItem = 69995, questItemCount = 1, } },
        --Moat Monster
        targets = 53590,
    },
    {
        --The Gnomish Bait-o-Matic
        questIDs = 29350,
        --Bait-o-Matic Blueprints, Hair Trigger, Rat Traps, Shiny Baubles
        questItems = { default = { questItem = 69979, },
                                 { questItem = 39684, questItemCount = 3, },
                                 { questItem = 69980, questItemCount = 3, },
                                 { questItem = 6529, questItemCount = 5, },
                     },
    },
    {
        --The Ring's the Thing
        questIDs = 29346,
        --Blind Cavefish
        questItems = { default = { questItem = 69956, }, },
    },
    {
        --The Sister's Pendant
        questIDs = 29346,
        --Giant Catfish
        questItems = { default = { questItem = 69914, }, },
    },
    --Jewelcrafing
    --Cataclysm
    {
        --The Latest Fashion!
        questIDs = 25157,
        --Stardust No. 2
        questItems = { default = { questItem = 52507, }, },
        func = function() return UnitCreatureType( "playertarget" ) == Humanoid; end,
    },
}

Baldrick:RegisterQuestModule( L["Profession Daily Quests"], professionDailyQuests, nil, 2 )
