--[[
    Baldrick_DailyQuests by LordFarlander
    Version 1.6.136
]]--

--[[
Copyright (c) 2012-2012, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--

-- $Revision: 136 $
-- $Date: 2012-04-08 18:38:32 +0000 (Sun, 08 Apr 2012) $

local Baldrick = _G["Baldrick"]

if( not Baldrick ) then
    error( L["%s requires %s"]:format( "Baldrick_WotLKDailyQuests", "Baldrick" ) )
    return
end--if

local L = LibStub( "AceLocale-3.0" ):GetLocale( "Baldrick_WotLKDailyQuests" )
local SpecialEventsAura = LibStub( "LibLordFarlander-SpecialEvents-Aura-4.0" )
local LBSZ = LibStub( "LibBabble-SubZone-3.0" )

if( LBSZ ) then
    LBSZ = LBSZ:GetUnstrictLookupTable()
end--if

local ZONES = {}
setmetatable( ZONES, {
    __index = function( self, key )
            return LBSZ and LBSZ[key] or L[key]
        end } )

local QuestObjectiveComplete = Baldrick.QuestObjectiveComplete

local function BuffNoHasCheck( quest )
    return not SpecialEventsAura:UnitHasBuff( "player", quest.buff )
end--BuffNoHasCheck( quest )

local function BuffNoHasCheck_DefaultItemName( quest )
    return not SpecialEventsAura:UnitHasBuff( "player", select( 1, GetItemInfo( quest.questItems.default.questItem ) ) )
end--BuffNoHasCheck_DefaultItemName( quest )

local function IsTargetAliveAndNotTapped()
    return not( UnitIsDead( "playertarget" ) ) and
           ( UnitIsTappedByPlayer( "playertarget" ) or not( UnitIsTapped( "playertarget" ) ) )
end--IsTargetAliveAndNotTapped()

local function IsTargetDead()
    return UnitIsDead( "playertarget" )
end--IsTargetDead()

local function SubzoneObjectiveCheck( quest, questid, _, subzone )
    local objectives = quest.objectives

    for index, name in ipairs( quest.subZones ) do
        if( ( name == subzone ) and QuestObjectiveComplete( questid, objectives[index] ) ) then
            return false
        end--if
    end--for
    return true
end--SubzoneObjectiveCheck( quest, questid, _, subzone )

local function TargetObjectiveCheckDead( quest, questid, target )
    if( not UnitIsDead( "playertarget" ) ) then
        return false
    end--if

    local objectives = quest.objectives

    for index, questTarget in ipairs( quest.targets ) do
        if( ( target == questTarget ) and QuestObjectiveComplete( questid, objectives[index] ) ) then
            return false
        end--if
    end--for
    return true
end--TargetObjectiveCheckDead( quest, questid, target )

local wotlkDailyQuests = {
     --[[
        These are the availiable fields; required are marked with a *, optional fields must be nil:
        questIDs: *Either a number with a questID or a table of numbers with questIDs.
        questItems: *A table of items required for the quest.  The one with an index of default is what will show on the button
                    The fields for items are:
                        questItem: the itemID of the item
                        questItemCount: the MINIMUM number required (the comparison will be >= )
        zones: A zone name this quest is valid for, ot a table of zone names
        subZones: A subzone name this quest is valid for, ot a table of zone names
        target: NPCId of target to check for, or table of NPCIds for multiple targets
        addionalEvents: Either a string with the name of an additional event that this quest should be checked when fired,
                        or a table of strings with names.  Events from a library that uses CallBackHandler can be registered for
                        buy using LibraryName:Event syntax.
        func: A function that takes two parameters.  The first parameter is the quest data iself, the second parameter will hold
              the questID being used.  If used this function must return a boolean, true if this quest is valid to show on the button.
        onEVENT: A function that will be ran whenever the event is encountered and the quest is registered for it.
        ]]--
    --Northrend
    --Howling Fjord
    {
        --The Way to His Heart...
        questIDs = 11472,
        --Tasty Reef Fish
        questItems = { default = { questItem = 34127, }, },
        --Reef Bull
        targets = 24786,
        func = IsTargetAliveAndNotTapped,
    },
    {
        --The Way to His Heart...
        questIDs = 11472,
        --Anuniaq's Net
        questItems = { default = { questItem = 40946, }, },
        zones = ZONES["Howling Fjord"],
        subZones = { "", ZONES["Garvan's Reef"], },
    },
    {
        --Break the Blockade
        questIDs = 11153,
        --Petrov's Cluster Bombs
        questItems = { default = { questItem = 33098, }, },
        zones = ZONES["Howling Fjord"],
        subZones = ZONES["Shattered Straits"],
    },
    --Borean Tundra
    {
        --Drake Hunt
        questIDs = 11940,
        --Raelorasz's Spear
        questItems = { default = { questItem = 35506, }, },
        --Nexus Drake Hatchling
        targets = 26127,
        func = IsTargetAliveAndNotTapped,
    },
    --Ahn'kahet: The Old Kingdom
    {
        --All Things in Good Time
        questIDs = 13190,
        --Ahn'kahar Watcher's Corpse
        questItems = { default = { questItem = 43494, }, },
        zones = ZONES["Ahn'kahet: The Old Kingdom"],
    },
    --Grizzly Hills
    {
        --Smoke 'Em Out
        questIDs = { 12323, 12324, },
        --Smoke Bomb
        questItems = { default = { questItem = 37621, }, },
        zones = ZONES["Grizzly Hills"],
        subZones = ZONES["Venture Bay"],
    },
    {
        --Seared Scourge
        questIDs = { 12029, 12038, },
        --Mack's Dark Grog
        questItems = { default = { questItem = 35908, }, },
        zones = ZONES["Grizzly Hills"],
        subZones = { ZONES["Drak'Tharon Keep"], ZONES["Drak'Tharon Keep Entrance"], ZONES["Drak'Tharon Overlook"], },
    },
    --Zul'Drak
    {
        --Troll Patrol: Done to Death
        questIDs = 12568,
        --Incinerating Oil
        questItems = { default = { questItem = 38556, }, },
        --Defeated Argent Footman
        targets = { 28156, 28260, },
        norange = true,
    },
    {
        --Troll Patrol: High Standards
        questIDs = 12502,
        --Argent Crusade Banner
        questItems = { default = { questItem = 38544, }, },
        zones = ZONES["Zul'Drak"],
        subZones = ZONES["Drak'Sotra"],
    },
    {
        --Troll Patrol: Throwing Down
        questIDs = 12591,
        --High Impact Grenade
        questItems = { default = { questItem = 38574, }, },
        zones = ZONES["Zul'Drak"],
        subZones = ZONES["Drak'Sotra"],
    },
    {
        --Troll Patrol: Can You Dig It?
        questIDs = 12588,
        --Steel Spade
        questItems = { default = { questItem = 38566, }, },
        zones = ZONES["Zul'Drak"],
    },
    --Sholazar Basin
    {
        --A Hero's Headgear
        questIDs = 12758,
        --Venture Co. Explosives
        questItems = { default = { questItem = 39651, }, },
        --Stormwatcher
        targets = 28877,
        func = IsTargetDead,
    },
    {
        --Rejek: First Blood
        questIDs = 12734,
        --Rejek's Blade
        questItems = { default = { questItem = 39577, }, },
        --Hardknuckle Charger, Sapphire Hive Wasp, Mistwhisper Oracle, Mistwhisper Warrior
        targets = { 28096, 28086, 28110, 28109, },
        func = TargetObjectiveCheckDead,
        --nonstandard
        objectives = { 1, 2, 3, 3, },
    },
    {
        --Power of the Great Ones
        questIDs = 12762,
        --Energized Polished Crystal
        questItems = { default = { questItem = 39748, }, },
        additionalEvents = { "LibLordFarlander-SpecialEvents-Aura-4.0:PlayerBuffGained",
                             "LibLordFarlander-SpecialEvents-Aura-4.0:PlayerBuffLost"
                           },
        zones = ZONES["Sholazar Basin"],
        subZones = ZONES["Kartak's Hold"],
        func = BuffNoHasCheck,
        --nonstandard
        --Power of the Great Ones
        buff = 53371,
    },
    {
        --The Heartblood's Strength
        questIDs = 12732,
        --Rejek's Vial
        questItems = { default = { questItem = 39574, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = ZONES["The Suntouched Pillar"],
    },
    {
        --Will of the Titans
        questIDs = 12705,
        --Tainted Crystal
        questItems = { default = { questItem = 39266, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = ZONES["Sparktouched Haven"],
    },
    {
        --Song of Fecundity
        questIDs = 12737,
        --Horn of Fecundity
        questItems = { default = { questItem = 39599, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = ZONES["The Stormwright's Shelf"],
    },
    {
        --Song of Reflection
        questIDs = 12736,
        --Didgeridoo of Contemplation
        questItems = { default = { questItem = 39598, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = { ZONES["The Glimmering Pillar"],
                     ZONES["The Suntouched Pillar"],
                     ZONES["The Mosslight Pillar"],
                     ZONES["The Skyreach Pillar"],
                   },
        func = SubzoneObjectiveCheck,
        --nonstandard
        objectives = { 1, 2, 3, 3, },
    },
    {
        --Song of Wind and Water
        questIDs = { 12726 },
        --Drums of the Tempest
        questItems = { default = { questItem = 39571, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = ZONES["The Stormwright's Shelf"],
    },
    {
        --Power of the Great Ones
        questIDs = 12762,
        --Dormant Polished Crystal
        questItems = { default = { questItem = 39747, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = ZONES["The Lifeblood Pillar"],
    },
    {
        --Kartak's Rampage
        questIDs = 12703,
        --Oracle Blood
        questItems = { default = { questItem = 39265, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = ZONES["Kartak's Hold"],
    },
    {
        --Appeasing the Great Rain Stone
        --Gods like Shiny Things
        questIDs = { 12704, 12572 },
        --Lafoo's Bug Bag
        questItems = { default = { questItem = 38622, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = { ZONES["Rainspeaker Canopy"], ZONES["Wildgrowth Mangal"], },
    },
    {
        --Appeasing the Great Rain Stone
        questIDs = { 12704 },
        --Jaloot's Favorite Crystal
        questItems = { default = { questItem = 38623, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = { ZONES["Rainspeaker Canopy"], ZONES["Wildgrowth Mangal"], },
    },
    {
        --Appeasing the Great Rain Stone
        questIDs = { 12704 },
        --Moodle's Stress Ball
        questItems = { default = { questItem = 38624, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = { ZONES["Rainspeaker Canopy"], ZONES["Wildgrowth Mangal"], },
    },
    {
        --A Cleansing Song
        questIDs = 12735,
        --Chime of Cleansing
        questItems = { default = { questItem = 39572, }, },
        zones = ZONES["Sholazar Basin"],
        subZones = { ZONES["River's Heart"], ZONES["Wintergrasp River"], ZONES["Bittertide Lake"], },
        func = SubzoneObjectiveCheck,
        --nonstandard
        objectives = { 1, 2, 3, },
    },
    {
        --Secret Strength of the Frenzyheart
        questIDs = 12760,
        --Wolvar Berries
        --Thunderbrew's Hard Ale
        questItems = { default = { questItem = 39739, }, { questItem = 39738, }, },
    },
    {
        --Secret Strength of the Frenzyheart
        questIDs = 12760,
        --Secret Strength of the Frenzyheart
        questItems = { default = { questItem = 39737, }, },
        zones = ZONES["Sholazar Basin"],
        additionalEvents = { "LibLordFarlander-SpecialEvents-Aura-4.0:PlayerBuffGained",
                             "LibLordFarlander-SpecialEvents-Aura-4.0:PlayerBuffLost"
                           },
        func = BuffNoHasCheck_DefaultItemName,
    },
    {
        --Chicken Party!
        --Flown the Coop!
        questIDs = { 12702, 12532 },
        --Chicken Net
        questItems = { default = { questItem = 38689, }, },
        zones = ZONES["Sholazar Basin"],
    },
    --The Storm Peaks
    {
        --Maintaining Discipline
        --Discipline
        questIDs = { 13422, 12906 },
        --Disciplining Rod
        questItems = { default = { questItem = 42837, }, },
        --Exhausted Vrykul
        targets = 30146,
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Blowing Hodir's Horn
        questIDs = 12977,
        --Hodir's Horn
        questItems = { default = { questItem = 42164, }, },
        --Niffelem Forefather, Restless Frostborn Ghost, Restless Frostborn Warrior,
        targets = { 29974, 30144, 30135, },
        func = TargetObjectiveCheckDead,
        --nonstandard
        objectives = { 1, 2, 2, },
    },
    {
        --Feeding Arngrim
        questIDs = 13046,
        --Arngrim's Tooth
        questItems = { default = { questItem = 42774, }, },
        --Roaming Jormungar
        targets = 30422,
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Thrusting Hodir's Spear
        questIDs = 13003,
        --Hodir's Spear
        questItems = { default = { questItem = 42769, }, },
        --Wild Wyrm
        targets = 30275,
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Spy Hunter
        questIDs = 12994,
        --Ethereal Worg's Fang
        questItems = { default = { questItem = 42479, }, },
        zones = ZONES["The Storm Peaks"],
        subZones = ZONES["Valley of Ancient Winters"],
    },
    {
        --Hot and Cold
        questIDs = 12981,
        --Essence of Ice
        questItems = { default = { questItem = 42246, }, },
        zones = ZONES["The Storm Peaks"],
        subZones = ZONES["Fjorn's Anvil"],
    },
    {
        --Overstock
        questIDs = 12833,
        --Improved Land Mines
        questItems = { default = { questItem = 40676, }, },
        zones = ZONES["The Storm Peaks"],
        subZones = ZONES["Garm's Bane"],
    },
    {
        --Back to the Pit
        --Into the Pit
        questIDs = { 13424, 12997 },
        --Reins of the Icemaw Matriarch
        questItems = { default = { questItem = 42499, }, },
        zones = ZONES["The Storm Peaks"],
        subZones = ZONES["The Pit of the Fang"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --The Aberrations Must Die
        --Aberrations
        questIDs = { 13425, 12925 },
        --Vial of Frost Oil
        questItems = { default = { questItem = 41612, }, },
        zones = ZONES["The Storm Peaks"],
        subZones = ZONES["The Blighted Pool"],
    },
    --Icecrown
    {
        --Drag and Drop
        questIDs = { 13323, 13353, 13318, 13352, },
        --Orb of Illusion
        questItems = { default = { questItem = 44246, }, },
        --Dark Subjugator
        targets = 32236,
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Life or Death
        questIDs = 12296,
        --Renewing Bandage
        questItems = { default = { questItem = 37576, }, },
        --Wounded Westfall Infantry
        targets = 27482,
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Overwhelmed!
        questIDs = 12288,
        --Renewing Tourniquet
        questItems = { default = { questItem = 37568, }, },
        --Wounded Skirmisher
        targets = 27463,
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Leave Our Mark!
        questIDs = 12995,
        --Ebon Blade Banner
        questItems = { default = { questItem = 42480, }, },
        --Jotunheim Warrior, Njorndar Spear-Sister, Valhalas Vargul, Mjordin Water Magus
        targets = { 29880, 30243, 30250, 30632, },
        func = IsTargetDead,
    },
    {
        --Not a Bug
        questIDs = { 13344, 13365, 13358, 13342, },
        --Rod of Siphoning
        questItems = { default = { questItem = 44009, }, },
        --Enslaved Minion <Void Summoner's Pet>
        targets = 32260,
        func = IsTargetDead,
    },
    {
        --From Their Corpses, Rise!
        questIDs = 12813,
        --Darkmender's Tincture
        questItems = { default = { questItem = 40587, }, },
        --Onslaught Darkweaver, Onslaught Gryphon Rider, Onslaught Harbor Guard, Onslaught Paladin, Onslaught Raven Bishop
        targets = { 29614, 29333, 29330, 29329, 29338, },
        zone = ZONES["Icecrown"],
        subZones = ZONES["Onslaught Harbor"],
        func = IsTargetDead,
    },
    {
        --No Fly Zone
        questIDs = 12815,
        --Bone Gryphon
        questItems = { default = { questItem = 40600, }, },
        zone = ZONES["Icecrown"],
        subZones = ZONES["Onslaught Harbor"],
        additionalEvents = { "LibLordFarlander-SpecialEvents-Aura-4.0:PlayerBuffGained",
                             "LibLordFarlander-SpecialEvents-Aura-4.0:PlayerBuffLost"
                           },
        func = BuffNoHasCheck_DefaultItemName,
    },
    {
        --The Solution Solution
        questIDs = 13292,
        --Smuggled Solution, Abandoned Helm, Abandoned Armor, Pile of Bones
        questItems = { default = { questItem = 44048, },
                                 { questItem = 43610, },
                                 { questItem = 43616, },
                                 { questItem = 43609, },
                     },
        zone = ZONES["Icecrown"],
        subZones = ZONES["The Broken Front"],
    },
    {
        --Volatility
        questIDs = 13261,
        --Copperclaw's Volatile Oil, Abandoned Helm, Abandoned Armor, Pile of Bones
        questItems = { default = { questItem = 43608, },
                                 { questItem = 43610, },
                                 { questItem = 43616, },
                                 { questItem = 43609, },
                     },
        zone = ZONES["Icecrown"],
        subZones = ZONES["The Broken Front"],
    },
    {
        --Neutralizing the Plague
        questIDs = { 13281, 13297, },
        --Pustulant Spinal Fluid
        questItems = { default = { questItem = 44010, }, },
        zone = ZONES["Icecrown"],
        subZones = ZONES["Mord'rethar: The Death Gate"],
    },
    {
        --Retest Now
        questIDs = { 13322, 13357, 13321, 13356, },
        --Writhing Mass
        questItems = { default = { questItem = 44304, }, },
        zone = ZONES["Icecrown"],
        --subZones = ZONES["Aldur'Thar: The Desolation Gate"],
    },
    {
        --That's Abominable!
        questIDs = { 13264, 13276, 13288, 13289, },
        --Abomination Reanimation Kit, Chilled Abomination Guts
        questItems = { default = { questItem = 43968, }, { questItem = 43966, }, },
    },
    {
        --Neutralizing the Plague
        questIDs = { 13281, 13297, },
        --Flesh Giant Spine
        questItems = { default = { questItem = 44009, }, },
    },
    {
        --Retest Now
        questIDs = { 13322, 13357, 13321, 13356, },
        --Diluted Cult Tonic
        questItems = { default = { questItem = 44307, }, },
        additionalEvents = { "LibLordFarlander-SpecialEvents-Aura-4.0:PlayerBuffGained",
                             "LibLordFarlander-SpecialEvents-Aura-4.0:PlayerBuffLost"
                           },
        zone = ZONES["Icecrown"],
        subZones = ZONES["Aldur'Thar: The Desolation Gate"],
        func = BuffNoHasCheck,
        --nonstandard
        --Dark Discernment
        buff = 60311,
    },
    {
        --Retest Now
        questIDs = { 13322, 13357, 13321, 13356, },
        --Tainted Essence
        questItems = { default = { questItem = 44301, questItemCount = 10, }, },
    },

    --Argent Tournament
    -- { --Retired
        -- --A Chip Off the Ulduar Block
        -- questIDs = 13681,
        -- --Goblin Chisel
        -- questItems = { default = { questItem = 45281, }, },
        -- zones = ZONES["The Storm Peaks"],
    -- },
    -- { --Retired
        -- --Jack Me Some Lumber
        -- questIDs = 13627,
        -- --Lumberjack's Axe
        -- questItems = { default = { questItem = 45046, }, },
        -- --Crystalsong Oak
        -- targets = 33308,
    -- },
    {
        --The Edge Of Winter
        questIDs = { 13603, 13670, 13675, 13743, 13748, 13754, 13754, 13759, 13616, 13764, 13770, 13775, 13780, 13785 },
        --Everburning Ember
        questItems = { default = { questItem = 45005, }, },
        --Maiden of Winter's Breath
        targets = 33303,
    },
    {
        --A Worthy Weapon
        questIDs = { 13600, 13669, 13674, 13742, 13747, 13753, 13758, 13763, 13769, 13774, 13779, 13784 },
        --Winter Hyacinth
        questItems = { default = { questItem = 45000, questItemCount = 4, }, },
        zones = ZONES["Dragonblight"],
        subZones = ZONES["Drak'Mar Lake"],
    },
    {
        --A Blade Fit For A Champion
        questIDs = { 13603, 13666, 13673, 13741, 13746, 13752, 13757, 13762, 13768, 13773, 13778, 13783, },
        --Warts-B-Gone Lip Balm
        questItems = { default = { questItem = 44986, }, },
        --Lake Frog
        targets = { 33211, 33224, },
        func = BuffNoHasCheck,
        --nonstandard
        --Warts-B-Gone Lip Balm
        buff = 62574,
    },
    {
        --A Blade Fit For A Champion
        questIDs = { 13603, 13666, 13673, 13741, 13746, 13752, 13757, 13762, 13768, 13773, 13778, 13783, },
        --/kiss
        questItems = { default = { questAction = { macro = "/kiss", icon = [[Interface\AddOns\Baldrick\Img\Kiss]], description = L["Kiss"], }, }, },
        --Lake Frog
        targets = { 33211, 33224, },
        func = function() return SpecialEventsAura:UnitHasBuff( "player", quest.buff ); end,
        --nonstandard
        --Warts-B-Gone Lip Balm
        buff = 62574,
    },
    --3.2
    {
        --Breakfast Of Champions
        questIDs = { 14076, 14092, },
        --Earthshaker Drum
        questItems = { default = { questItem = 46893, }, },
        zones = ZONES["The Storm Peaks"],
        subZones = ZONES["The Foot Steppes"],
    },
    {
        --Get Kraken!
        questIDs = 14108,
        --Flaming Spears
        questItems = { default = { questItem = 47006, }, },
        --Kvaldir Deepcaller, North Sea Kraken
        targets = { 35092, 34925, },
        norange = true,
        func = function( quest, questid, target )
                   if( UnitIsDead( "playertarget" ) ) then
                       return false
                   end--if
                   local objectives = quest.objectives

                   for index, questTarget in ipairs( quest.targets ) do
                       if( ( target == questTarget ) and QuestObjectiveComplete( questid, objectives[index] ) ) then
                           return false
                       end--if
                   end--for
                   return true
               end,
        --nonstandard
        objectives = { 1, 2, },
    },
    {
        --The Light's Mercy
        questIDs = { 14077, 14144, },
        --Confessor's Prayer Book
        questItems = { default = { questItem = 46870, }, },
        --Slain Tualiq Villager
        targets = 34852,
        norange = true,
    },
    {
        --Drottinn Hrothgar
        questIDs = 14101,
        --Kvaldir War Horn
        questItems = { default = { questItem = 47006, }, },
        zones = ZONES["Hrothgar's Landing"],
    },
    {
        --Mistcaller Yngvar
        questIDs = 14102,
        --Mistcaller's Charm
        questItems = { default = { questItem = 47009, }, },
        zones = ZONES["Hrothgar's Landing"],
    },
    {
        --Ornolf The Scarred
        questIDs = 14104,
        --Captured Kvaldir Banner
        questItems = { default = { questItem = 47029, }, },
        zones = ZONES["Hrothgar's Landing"],
    },
    {
        --Gormok Wants His Snobolds
        questIDs = { 14090, 14141, },
        --Weighted Net
        questItems = { default = { questItem = 46885, }, },
        --Snowblind Follower
        targets = 29618,
        func = IsTargetAliveAndNotTapped,
        norange = true,
    },
    {
        --The Fate Of The Fallen
        questIDs = 14107,
        --Light-Blessed Relic, Discarded Soul Crystal
        questItems = { default = { questItem = 47033, }, { questItem = 47035, }, },
        targets = 32149,
        func = IsTargetAliveAndNotTapped,
    },
    {
        --What Do You Feed a Yeti, Anyway?
        questIDs = { 14112, 14145, },
        --Fresh Chum
        questItems = { default = { questItem = 47036, }, },
        func = IsSwimming,
    },
}

Baldrick:RegisterQuestModule( L["Wrath of the Lich King Daily Quests"], wotlkDailyQuests, nil, 2 )
